@@ -25,6 +25,7 @@ class Partner:
         coop_agreement_code,
         sponsor_id,
         coop_candidate,
+        member,
         **kwargs
     ):
         self.id = id
@@ -43,6 +44,7 @@ class Partner:
         self.sponsor_id = sponsor_id
         self.coop_agreement_code = coop_agreement_code
         self.coop_candidate = coop_candidate
+        self.member = member
 
     @classmethod
     def get(cls, ref):
